@@ -36,7 +36,7 @@ use URI::Escape;
 use constant DEBUG => $ENV{DEBUG};
 use if DEBUG, 'Smart::Comments';
 
-our $VERSION = '1.64'; # VERSION
+our $VERSION = '1.65'; # VERSION
 
 # Required to successfully read extra long headers returned from yahoo
 my %OPTS = @LWP::Protocol::http::EXTRA_SOCK_OPTS;
@@ -45,30 +45,33 @@ $OPTS{MaxLineLength} = 16384;
 
 my $YIND_URL_HEAD = 'https://query2.finance.yahoo.com/v11/finance/quoteSummary/?symbols=';
 my $YIND_URL_TAIL = '&modules=price,summaryDetail,defaultKeyStatistics';
-my $browser = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36';
+#my $browser = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/133.0.0.0 Safari/537.36';
+my $browser = 'Mozilla/5.0';
 
-sub methods {
-    return (
-      yahoo_json => \&yahoo_json,
-      yahoojson  => \&yahoo_json,
-      usa        => \&yahoo_json,
-      nyse       => \&yahoo_json,
-      nasdaq     => \&yahoo_json,
+our $DISPLAY    = 'YahooJSON';
+our @LABELS     = qw/name last date isodate volume currency method exchange type
+        div_yield eps pe year_range open high low close/;
+our $METHODHASH = {subroutine => \&yahoo_json, 
+                   display => $DISPLAY, 
+                   labels => \@LABELS};
+
+sub methodinfo {
+    return ( 
+        yahoo_json  => $METHODHASH,
+        yahoojson   => $METHODHASH,
+        nyse        => $METHODHASH,
+        nasdaq      => $METHODHASH,
+        usa         => $METHODHASH,
     );
 }
-{
-    my @labels = qw/name last date isodate volume currency method exchange type
-        div_yield eps pe year_range open high low close/;
 
-    sub labels {
-        return (
-          yahoo_json => \@labels,
-          yahoojson  => \@labels,
-          usa        => \@labels,
-          nyse       => \@labels,
-          nasdaq     => \@labels,
-        );
-    }
+sub labels {
+  my %m = methodinfo();
+  return map {$_ => [@{$m{$_}{labels}}] } keys %m;
+}
+
+sub methods {
+  my %m = methodinfo(); return map {$_ => $m{$_}{subroutine} } keys %m;
 }
 
 sub yahoo_json {
@@ -216,39 +219,6 @@ sub yahoo_json {
                 $info{ $stocks, "currency"} = $json_resources_price->{'currency'};
                 $info{ $stocks, "volume" }   = $json_volume;
 
-                # The Yahoo JSON interface returns London prices in GBp (pence) instead of GBP (pounds)
-                # and the Yahoo Base had a hack to convert them to GBP.  In theory all the callers
-                # would correctly handle GBp as not the same as GBP, but they don't, and since
-                # we had the hack before, let's add it back now.
-                #
-                # Convert GBp or GBX to GBP (divide price by 100).
-
-                if ( ($info{$stocks,"currency"} eq "GBp") ||
-                     ($info{$stocks,"currency"} eq "GBX")) {
-                    $info{$stocks,"last"}=$info{$stocks,"last"}/100;
-                    $info{ $stocks, "currency"} = "GBP";
-                }
-
-                # Apply the same hack for Johannesburg Stock Exchange
-                # (JSE) prices as they are returned in ZAc (cents)
-                # instead of ZAR (rands). JSE symbols are suffixed
-                # with ".JO" when querying Yahoo e.g. ANG.JO
-
-                if ($info{$stocks,"currency"} eq "ZAc") {
-                    $info{$stocks,"last"}=$info{$stocks,"last"}/100;
-                    $info{ $stocks, "currency"} = "ZAR";
-                }
-
-                # Apply the same hack for Tel Aviv Stock Exchange
-                # (TASE) prices as they are returned in ILA (Agorot)
-                # instead of ILS (Shekels). TASE symbols are suffixed
-                # with ".TA" when querying Yahoo e.g. POLI.TA
-
-                if ($info{$stocks,"currency"} eq "ILA") {
-                    $info{$stocks,"last"}=$info{$stocks,"last"}/100;
-                    $info{ $stocks, "currency"} = "ILS";
-                }
-
             # Add extra fields using names as per yahoo to make it easier
             #  to switch from yahoo to yahooJSON
             # Code added by goodvibes
@@ -258,7 +228,7 @@ sub yahoo_json {
                   # in Strawberry perl 5.18.2 in Windows
                   local $^W = 0;
                   $info{ $stocks, "div_yield" } =
-                    $json_resources_summaryDetail->{'trailingAnnualDividendYield'}{'raw'} =~ m/[\d,\.]+/ ?
+                    $json_resources_summaryDetail->{'trailingAnnualDividendYield'}{'raw'} =~ m/^[\d,\.]+$/ ?
                     $json_resources_summaryDetail->{'trailingAnnualDividendYield'}{'raw'} * 100          :
                     0.0;
                 }
@@ -279,6 +249,50 @@ sub yahoo_json {
                 $info{ $stocks, "close"} =
                     $json_resources_summaryDetail->{'regularMarketPreviousClose'}{'raw'};
 
+                # The Yahoo JSON interface can London prices in
+                # GBp (pence) instead of GBP (pounds) and the Yahoo Base
+                # had a hack to convert them to GBP. In theory all the
+                # callers would correctly handle GBp as not the same as GBP,
+                # but they don't, and since we had the hack before,
+                # let's add it back now.
+                # Convert GBp or GBX to GBP (divide price by 100).
+
+                if ( ($info{$stocks,"currency"} eq "GBp") ||
+                     ($info{$stocks,"currency"} eq "GBX")) {
+                    foreach my $field ($quoter->get_default_currency_fields) {
+                        next unless ( $info{ $stocks, $field } );
+                        $info{$stocks, $field} =
+                          $quoter->scale_field($info{ $stocks, $field }, 0.01);
+                    }
+                    $info{ $stocks, "currency"} = "GBP";
+                }
+
+                # Apply the same hack for Johannesburg Stock Exchange
+                # (JSE) prices as they are returned in ZAc (cents)
+                # instead of ZAR (rands). JSE symbols are suffixed
+                # with ".JO" when querying Yahoo e.g. ANG.JO
+                if ( $info{$stocks,"currency"} eq "ZAc") {
+                    foreach my $field ($quoter->get_default_currency_fields) {
+                        next unless ( $info{ $stocks, $field } );
+                        $info{$stocks, $field} =
+                          $quoter->scale_field($info{ $stocks, $field }, 0.01);
+                    }
+                    $info{ $stocks, "currency"} = "ZAR";
+                }
+
+                # Apply the same hack for Tel Aviv Stock Exchange
+                # (TASE) prices as they are returned in ILA (Agorot)
+                # instead of ILS (Shekels). TASE symbols are suffixed
+                # with ".TA" when querying Yahoo e.g. POLI.TA
+                if ( $info{$stocks,"currency"} eq "ILA") {
+                    foreach my $field ($quoter->get_default_currency_fields) {
+                        next unless ( $info{ $stocks, $field } );
+                        $info{$stocks, $field} =
+                          $quoter->scale_field($info{ $stocks, $field }, 0.01);
+                    }
+                    $info{ $stocks, "currency"} = "ILS";
+                }
+
                 # MS Windows strftime() does not support %T so use %H:%M:%S
                 #  instead.
                 $my_date =
